@@ -44,7 +44,7 @@ class Client(object):
     def call_method(self, method, param=None):
         """Calls an API method."""
         for attempt in range(10):
-            delay = 5 * (attemp + 1)
+            delay = 5 * (attempt + 1)
 
             try:
                 payload = {"method": method, "application_id": self.application_id,
@@ -102,7 +102,7 @@ class Client(object):
         finally:
             if self.logger:
                 self.logger.debug("Fetching %s, args: %s, request=%u, took %.2f seconds." \
-                    % (url, args, self.request_count - 1, time.time() - ts))
+                    % (url, args, self.request_count, time.time() - ts))
 
     def __repr__(self):
         return "<yandexdirect.Client application_id=%s login=%s>" % (self.application_id, self.login)
@@ -171,7 +171,12 @@ class Client(object):
         return banners
 
     def GetBannerPhrases(self, banner_ids):
-        return self.call_method("GetBannerPhrases", banner_ids)
+        phrases = []
+        while banner_ids:
+            phrases.extend(self.call_method("GetBannerPhrases",
+                banner_ids[:1000]))
+            del banner_ids[:1000]
+        return phrases
 
     def GetClientInfo(self, names):
         return self.call_method("GetClientInfo", names)
